# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dji.proto
# Protobuf Python Version: 5.29.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 29, 3, "", "dji.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\tdji.proto"\x87\x01\n\rDjiModuleInfo\x12\x12\n\nproto_name\x18\x01 \x01(\t\x12\x0c\n\x04unk1\x18\x02 \x01(\t\x12\x0c\n\x04unk2\x18\x03 \x01(\t\x12\x15\n\rserial_number\x18\x05 \x01(\t\x12\x0c\n\x04unk4\x18\x06 \x01(\t\x12\x0c\n\x04unk5\x18\t \x01(\r\x12\x13\n\x0b\x63\x61mera_name\x18\n \x01(\t"9\n\x12\x44jiVideoGlobalInfo\x12#\n\x0bmodule_info\x18\x01 \x03(\x0b\x32\x0e.DjiModuleInfo"W\n\x16\x44jiRemoteGpsDeviceInfo\x12\x0c\n\x04unk1\x18\x01 \x01(\r\x12\x0c\n\x04unk2\x18\x02 \x01(\r\x12\x13\n\x0b\x64\x65vice_name\x18\x04 \x01(\t\x12\x0c\n\x04unk3\x18\x05 \x01(\x02"\\\n\x1b\x44jiRemoteGpsCoordinatesInfo\x12\x18\n\x10\x63oordinate_units\x18\x01 \x01(\r\x12\x10\n\x08latitude\x18\x02 \x01(\x01\x12\x11\n\tlongitude\x18\x03 \x01(\x01"\'\n\x13\x43oordinatesDatetime\x12\x10\n\x08\x64\x61tetime\x18\x01 \x01(\t"\xa2\x01\n\x17\x44jiRemoteGpsCoordinates\x12*\n\x04info\x18\x01 \x01(\x0b\x32\x1c.DjiRemoteGpsCoordinatesInfo\x12\x17\n\x0fgps_altitude_mm\x18\x02 \x01(\r\x12\x0c\n\x04unk2\x18\x04 \x01(\r\x12\x0c\n\x04unk3\x18\x05 \x01(\r\x12&\n\x08\x64\x61tetime\x18\x06 \x01(\x0b\x32\x14.CoordinatesDatetime"6\n\x13\x44jiRemoteDerivative\x12\t\n\x01x\x18\x01 \x01(\x02\x12\t\n\x01y\x18\x02 \x01(\x02\x12\t\n\x01z\x18\x03 \x01(\x02"\x9a\x01\n\x10\x44jiRemoteGpsInfo\x12,\n\x0b\x64\x65vice_info\x18\x01 \x01(\x0b\x32\x17.DjiRemoteGpsDeviceInfo\x12-\n\x0b\x63oordinates\x18\x02 \x01(\x0b\x32\x18.DjiRemoteGpsCoordinates\x12)\n\x0b\x64\x65rivatives\x18\x03 \x01(\x0b\x32\x14.DjiRemoteDerivative" \n\rDjiUnkfloat_1\x12\x0f\n\x07unknown\x18\x01 \x01(\x02" \n\rDjiUnkInt32_1\x12\x0f\n\x07unknown\x18\x01 \x01(\x05"!\n\x0e\x44jiUnkUInt32_1\x12\x0f\n\x07unknown\x18\x01 \x01(\r")\n\x10\x44jiUnkRepBytes_1\x12\x15\n\runknown_field\x18\x01 \x03(\x0c"B\n\x12\x44jiCameraAccelInfo\x12\x0b\n\x03unk\x18\x01 \x01(\x02\x12\t\n\x01x\x18\x02 \x01(\x02\x12\t\n\x01y\x18\x03 \x01(\x02\x12\t\n\x01z\x18\x04 \x01(\x02"\xcc\x02\n\rDjiCameraInfo\x12\x1c\n\x04unk1\x18\x02 \x01(\x0b\x32\x0e.DjiUnkfloat_1\x12\x1c\n\x04unk2\x18\x03 \x01(\x0b\x32\x0e.DjiUnkfloat_1\x12\x1f\n\x04unk3\x18\x04 \x01(\x0b\x32\x11.DjiUnkRepBytes_1\x12\x1c\n\x04unk4\x18\x05 \x01(\x0b\x32\x0e.DjiUnkfloat_1\x12\x1d\n\x04unk5\x18\x06 \x01(\x0b\x32\x0f.DjiUnkUInt32_1\x12\x1d\n\x04unk6\x18\x07 \x01(\x0b\x32\x0f.DjiUnkUInt32_1\x12\x0c\n\x04unk7\x18\x08 \x01(\r\x12+\n\x0e\x61\x63\x63\x65lerometer1\x18\t \x01(\x0b\x32\x13.DjiCameraAccelInfo\x12+\n\x0e\x61\x63\x63\x65lerometer2\x18\n \x01(\x0b\x32\x13.DjiCameraAccelInfo\x12\x0c\n\x04unk8\x18\x0b \x01(\r\x12\x0c\n\x04unk9\x18\x0c \x01(\r"1\n\x0cGpsFrameInfo\x12\x10\n\x08\x66rame_id\x18\x01 \x01(\r\x12\x0f\n\x07unknown\x18\x02 \x01(\r"\x80\x01\n\nDjiGpsInfo\x12!\n\nframe_info\x18\x01 \x01(\x0b\x32\r.GpsFrameInfo\x12#\n\x0b\x63\x61mera_info\x18\x02 \x01(\x0b\x32\x0e.DjiCameraInfo\x12*\n\x0fremote_gps_info\x18\x04 \x01(\x0b\x32\x11.DjiRemoteGpsInfo"\x83\x01\n\x16VideoStreamInfoDetails\x12\r\n\x05width\x18\x01 \x01(\r\x12\x0e\n\x06height\x18\x02 \x01(\r\x12\x12\n\nframe_rate\x18\x03 \x01(\x02\x12\x0c\n\x04unk1\x18\x04 \x01(\r\x12\x0c\n\x04unk2\x18\x05 \x01(\r\x12\x0c\n\x04unk3\x18\x06 \x01(\r\x12\x0c\n\x04unk5\x18\x08 \x01(\r"I\n\x0fVideoStreamInfo\x12\x0c\n\x04type\x18\x01 \x01(\t\x12(\n\x07\x64\x65tails\x18\x03 \x01(\x0b\x32\x17.VideoStreamInfoDetails"\x8c\x01\n\x0eGenericMessage\x12.\n\x11video_global_info\x18\x01 \x01(\x0b\x32\x13.DjiVideoGlobalInfo\x12+\n\x11video_stream_info\x18\x02 \x01(\x0b\x32\x10.VideoStreamInfo\x12\x1d\n\x08gps_info\x18\x03 \x03(\x0b\x32\x0b.DjiGpsInfob\x06proto3'  # noqa: E501
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "dji_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals["_DJIMODULEINFO"]._serialized_start = 14
    _globals["_DJIMODULEINFO"]._serialized_end = 149
    _globals["_DJIVIDEOGLOBALINFO"]._serialized_start = 151
    _globals["_DJIVIDEOGLOBALINFO"]._serialized_end = 208
    _globals["_DJIREMOTEGPSDEVICEINFO"]._serialized_start = 210
    _globals["_DJIREMOTEGPSDEVICEINFO"]._serialized_end = 297
    _globals["_DJIREMOTEGPSCOORDINATESINFO"]._serialized_start = 299
    _globals["_DJIREMOTEGPSCOORDINATESINFO"]._serialized_end = 391
    _globals["_COORDINATESDATETIME"]._serialized_start = 393
    _globals["_COORDINATESDATETIME"]._serialized_end = 432
    _globals["_DJIREMOTEGPSCOORDINATES"]._serialized_start = 435
    _globals["_DJIREMOTEGPSCOORDINATES"]._serialized_end = 597
    _globals["_DJIREMOTEDERIVATIVE"]._serialized_start = 599
    _globals["_DJIREMOTEDERIVATIVE"]._serialized_end = 653
    _globals["_DJIREMOTEGPSINFO"]._serialized_start = 656
    _globals["_DJIREMOTEGPSINFO"]._serialized_end = 810
    _globals["_DJIUNKFLOAT_1"]._serialized_start = 812
    _globals["_DJIUNKFLOAT_1"]._serialized_end = 844
    _globals["_DJIUNKINT32_1"]._serialized_start = 846
    _globals["_DJIUNKINT32_1"]._serialized_end = 878
    _globals["_DJIUNKUINT32_1"]._serialized_start = 880
    _globals["_DJIUNKUINT32_1"]._serialized_end = 913
    _globals["_DJIUNKREPBYTES_1"]._serialized_start = 915
    _globals["_DJIUNKREPBYTES_1"]._serialized_end = 956
    _globals["_DJICAMERAACCELINFO"]._serialized_start = 958
    _globals["_DJICAMERAACCELINFO"]._serialized_end = 1024
    _globals["_DJICAMERAINFO"]._serialized_start = 1027
    _globals["_DJICAMERAINFO"]._serialized_end = 1359
    _globals["_GPSFRAMEINFO"]._serialized_start = 1361
    _globals["_GPSFRAMEINFO"]._serialized_end = 1410
    _globals["_DJIGPSINFO"]._serialized_start = 1413
    _globals["_DJIGPSINFO"]._serialized_end = 1541
    _globals["_VIDEOSTREAMINFODETAILS"]._serialized_start = 1544
    _globals["_VIDEOSTREAMINFODETAILS"]._serialized_end = 1675
    _globals["_VIDEOSTREAMINFO"]._serialized_start = 1677
    _globals["_VIDEOSTREAMINFO"]._serialized_end = 1750
    _globals["_GENERICMESSAGE"]._serialized_start = 1753
    _globals["_GENERICMESSAGE"]._serialized_end = 1893
# @@protoc_insertion_point(module_scope)
